#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

#Vhffs::ACL written by sod` <dieu AT gunnm DOT org>

# This software is free software, please read LICENCE file

use Vhffs::Constants;

use strict;
use diagnostics;

package Vhffs::Acl;

sub what_perm_for_user
{
	my $entity;
	my $object;
	my $main;
	my $perm;
	my $result;
	my $query;
	my $request;
	my $rows;

	$entity 	= 	shift;
	$object 	= 	shift;
	$main		=	shift;

	return -1 if( ( $entity->fetch < 0 ) || ( $object->fetch < 0 ) );

	$perm = Vhffs::Constants::ACL_DENIED;
	
	$query = "SELECT perm FROM vhffs_acl WHERE oid_src='".$entity->{'object_id'}."' AND oid_dst='".$object->{'object_id'} ."'";
	$request = $main->{'db'}->{'DB_READ'}->prepare( $query );
	$rows = $request->execute;

	if( $rows != 0 )
	{
		$result = $main->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
		$perm = $result->[0][0];
	}
	else
	{
		$query = "SELECT acl.perm FROM vhffs_acl acl, vhffs_groups groups, vhffs_user_group ug WHERE acl.oid_dst='".$object->{'object_id'} ."' AND ug.uid='".$entity->get_uid."' AND ug.gid=groups.gid AND groups.object_id=acl.oid_src";
		$request = $main->{'db'}->{'DB_READ'}->prepare( $query );
		$rows = $request->execute;

		if( $rows != 0 )
		{
			while( my @lol = $request->fetchrow_array )
			{
				$perm = $lol[0] if( $perm < $lol[0] );
			}
		}
	}
	return $perm;	
}

sub what_perm_for_group
{
	my $entity;
	my $object;
	my $main;
	my $query;
	my $request;
	my $result;
	my $rows;

	$entity		=	shift;
	$object		=	shift;
	$main		=	shift;

	return -1 if( ( $entity->fetch < 0 ) || ( $object->fetch < 0 ) );
	
	$query = "SELECT perm FROM vhffs_acl WHERE oid_src='".$entity->{'object_id'}."' AND oid_dst='".$object->{'object_id'} ."'";

	$request = $main->{'db'}->{'DB_READ'}->prepare( $query );
	$rows = $request->execute;

	if ( $rows != 0 )
	{
		$result = $main->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
		return $result->[0][0];
	}
	else
	{
		return 0;
	}
	
}


sub add_acl
{
	my ( $entity , $object , $perm , $main ) = @_;

	return -1 if( ( $entity->fetch < 0 ) || ( $object->fetch < 0 ) );

	my $query = "SELECT perm FROM vhffs_acl WHERE oid_src='".$entity->{'object_id'}."' AND oid_dst='".$object->{'object_id'} ."'";

	my $request = $main->{'db'}->{'DB_READ'}->prepare( $query );
	my $rows = $request->execute;

	#If the ACL already exists, we just update it
	if ( $rows > 0 )
	{
		$query = "UPDATE vhffs_acl SET perm='".$perm."' WHERE oid_src='".$entity->{'object_id'}."' AND oid_dst='".$object->{'object_id'} ."'";
	}	
	else
	{
		#If not, we create a new ACL in the database
		my $acl_id = 1;
		$query = "SELECT MAX(acl_id) FROM vhffs_acl";
		my $result = $main->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
		$acl_id = $result->[0][0] if ( defined $result->[0][0] );
		$acl_id++;

		$query = "INSERT INTO vhffs_acl VALUES('$acl_id' ,'".$entity->{'object_id'}."','$perm','".$object->{'object_id'}."')";
	}
	$request = $main->{'db'}->{'DB_WRITE'}->prepare( $query );
	$request->execute;

	return 1;
}



sub del_acl
{
	my ( $entity , $object , $main ) = @_;

	return -1 if( ( $entity->fetch < 0 ) || ( $object->fetch < 0 ) );

	my $query;
	my $request;
	my $result;
	my $rows;
	
	$query = "SELECT COUNT(*) FROM vhffs_acl WHERE perm IN ( '".Vhffs::Constants::ACL_MANAGEACL."', '".Vhffs::Constants::ACL_DELETE."') AND oid_dst='".$object->{'object_id'} ."'";
	$result = $main->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
	return -1 if( ( ! defined $result )  || ( ! defined $result->[0][0] ) || ( $result->[0][0] <= 1 ) );

	$query = "SELECT perm FROM vhffs_acl WHERE oid_src='".$entity->{'object_id'}."' AND oid_dst='".$object->{'object_id'} ."'";
	$request = $main->{'db'}->{'DB_READ'}->prepare( $query );
	$rows = $request->execute;


	if ( $rows != 0 )
	{
		my $query = "DELETE FROM vhffs_acl WHERE oid_src='".$entity->{'object_id'}."' AND oid_dst='".$object->{'object_id'} ."'";
		$request = $main->{'db'}->{'DB_WRITE'}->prepare( $query );
		$request->execute;
	}
	return 1;
}


sub getall_acl_for_user_per_object
{
	my ( $obj , $main ) = @_;
	return -1 if( $obj->fetch < 0 );

	my $query = "SELECT users.username, perm FROM vhffs_acl acl, vhffs_users users WHERE oid_src=users.object_id AND oid_dst='".$obj->{'object_id'} ."'"; 
	my $request = $main->{'db'}->{'DB_READ'}->prepare( $query );
	return undef if( $request->execute <= 0 );
	return ( $request->fetchall_hashref('username') );
}


sub getall_acl_for_group_per_object
{
	my $obj;
	my $main;
	my $query;
	my $request;

	$obj		=	shift;
	$main		=	shift;

	return -1 if( $obj->fetch < 0 );

	$query = "SELECT groups.groupname, perm FROM vhffs_acl acl, vhffs_groups groups WHERE oid_src=groups.object_id AND oid_dst='".$obj->{'object_id'} ."'"; 
	$request = $main->{'db'}->{'DB_READ'}->prepare( $query );
	return undef if( $request->execute <= 0 );
	return ( $request->fetchall_hashref('groupname') );
}



1;

