#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


package Vhffs::Panel::DNS;

use DBI;
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Constants;
use Vhffs::Acl;
use Vhffs::Services::DNS;


sub getall_domain_to_moderate
{
    my( $main , $query , $request);
    $main = shift;
    $query = "SELECT n.domain , o.description ,  u.username , g.groupname , o.object_id FROM vhffs_dns_global n, vhffs_object o , vhffs_users u , vhffs_groups g  WHERE u.uid=n.owner_uid AND g.gid=n.owner_gid AND n.object_id=o.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
	$request = $main->{'db'}->{'DB_READ'}->prepare( $query );

    return undef if ( $request->execute <= 0 );
    return( $request->fetchall_hashref('domain') );
}



sub getall_domains
{
        my $main = shift;
        my $name = shift;

        my $query;

    if( defined $name )
        {
                $query = "SELECT ns.domain, ns.object_id, ns.owner_gid, o.state  FROM vhffs_dns_global ns, vhffs_object o WHERE o.object_id=ns.object_id AND ns.domain LIKE '".$name."'";
        }
        else
        {
                $query = "SELECT ns.domain, ns.object_id, ns.owner_gid, o.state  FROM vhffs_dns_global ns, vhffs_object o WHERE o.object_id=ns.object_id";
        }
        my $request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -1;

        return undef if ( $request->execute() <= 0);

        return( $request->fetchall_hashref('domain') );
}



sub create_dns
{
    my ( $main , $dns_name , $user , $group ) = @_;
    return undef if( $user->fetch < 0 );
    return undef if( $group->fetch < 0 );

    my $dns = new Vhffs::Services::DNS( $main , $dns_name , $user , $group );
	return undef if( ! defined $dns );
    $dns->set_user( $user );
    $dns->set_group( $group );

    return undef if( $dns->create < 0 );

    return undef if ( Vhffs::Acl::add_acl( $user , $dns , Vhffs::Constants::ACL_DELETE , $main ) < 0 );
    return undef if( Vhffs::Acl::add_acl( $group , $dns , Vhffs::Constants::ACL_VIEW , $main ) < 0 );

    return $dns;
}


#Returns an array which contains | domain_name | object_id (from DNS)
sub getall_dns_per_user
{
	my ( $user , $main ) = @_ ;

	return undef if ( $user->fetch < 0 );

	my $query = "SELECT ns.domain, ns.object_id FROM vhffs_dns_global ns, vhffs_acl acl ,vhffs_users WHERE vhffs_users.object_id=acl.oid_src AND acl.oid_dst=ns.object_id AND vhffs_users.username='".$user->{'username'}."'";

	my $request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -1;

	return undef if ( $request->execute() <= 0);

	return( $request->fetchrow_arrayref() );	
}


sub getall_dns_per_group
{
	my ( $group , $main ) =@_ ;

	return undef if ( $group->fetch < 0 );

	my $query = "SELECT ns.domain, ns.object_id , o.object_id, o.state  FROM vhffs_dns_global ns , vhffs_object o WHERE o.object_id=ns.object_id AND ns.owner_gid='".$group->get_gid."'";
	my $request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -1;

	return undef if ( $request->execute() <= 0);

	return( $request->fetchall_hashref('domain') );
}


sub menu
{
	my ( $class , $data ) = @_;

	my $vhffs = $data->{'vhffs'};
	my $session = $data->{'session'};
	my $user = $data->{'user'};
	my $group = $data->{'group'};
	my $cgi = $data->{'cgi'};
	my $templatesdir = $vhffs->get_config->get_templatedir;
	my $template = new HTML::Template( filename => "$templatesdir/dns/menu.tmpl" );
	my $ns;
	$template->param( TEXT_CREATE => gettext("Create") );
	$template->param( TEXT_DNS => gettext("DNS") );

	my $output = "";
	my $domains = Vhffs::Services::DNS::getall( $vhffs , undef , undef , $group );
	my $subtemplate;
	foreach $ns ( @{$domains} )
	{
		if( $ns->get_status == Vhffs::Constants::ACTIVATED )
		{
			$subtemplate = new HTML::Template( filename => "$templatesdir/dns/menu_sub.tmpl" );
			$subtemplate->param( DOMAIN => $ns->get_domain );
            $subtemplate->param( HISTORY => Vhffs::Functions::status_string_from_status_id( $ns->get_status ) );
            $subtemplate->param( OID => $ns->get_oid );
			$output .= $subtemplate->output;
		}
		else
		{
			$subtemplate = new HTML::Template( filename => "$templatesdir/dns/menu_sub_wait.tmpl" );
			$subtemplate->param( DOMAIN => $ns->get_domain );
            $subtemplate->param( HISTORY => gettext("History") );
            $subtemplate->param( REASON => Vhffs::Functions::status_string_from_status_id( $ns->get_status ) );
            $subtemplate->param( OID => $ns->get_oid );
			$output .= $subtemplate->output;
		}
	}

	$template->param( SUB_DNS => $output );

	return $template->output;
}

1;
