#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


package Vhffs::Panel::Mysql;

use DBI;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Services::Mysql;

sub getall_dbs_to_moderate
{
        my( $main , $query , $request);
        $main = shift;
        $query = "SELECT m.dbname , o.description ,  u.username , g.groupname , o.object_id FROM vhffs_mysql m, vhffs_object o , vhffs_users u , vhffs_groups g  WHERE u.uid=m.owner_uid AND g.gid=m.owner_gid AND m.object_id=o.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
        $request = $main->{'db'}->{'DB_READ'}->prepare( $query );

        return undef if ( $request->execute <= 0 );
        return( $request->fetchall_hashref('dbname') );
}


sub getall_mysql
{
    my $main = shift; 
    my $name = shift;
    
        my $query;

    if( defined $name )
        {
                $query = "SELECT m.dbname, m.dbuser, m.object_id, m.owner_gid, o.state  FROM vhffs_mysql m, vhffs_object o WHERE o.object_id=m.object_id AND ( ( m.dbname LIKE '".$name."' ) OR ( m.dbuser LIKE '".$name."' ) )";
        }
        else
        {
                $query = "SELECT m.dbname, m.dbuser, m.object_id, m.owner_gid, o.state  FROM vhffs_mysql m, vhffs_object o WHERE o.object_id=m.object_id";
        }
        my $request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -1;
        
        return undef if ( $request->execute() <= 0);
        
        return( $request->fetchall_hashref('dbname') );
}




sub create_mysql
{
    my( $main , $dbname , $user , $group , $dbuser, $dbpass ) = @_;

    return -1 if( $user->fetch < 0 );
    return -2 if( $group->fetch < 0 );

    my $mysql = new Vhffs::Services::Mysql( $main , $dbname , $user , $group );

    return undef if( ! defined $mysql );

    $mysql->set_user( $user );
    $mysql->set_group( $group );

    return undef if ( $mysql->set_dbusername( $dbuser ) < 0 );
    return undef if ( $mysql->set_dbpassword( $dbpass ) < 0 );

    return undef if( $mysql->create < 0 );

    return undef if ( Vhffs::Acl::add_acl( $user , $mysql , Vhffs::Constants::ACL_DELETE , $main ) < 0 );
    return undef if ( Vhffs::Acl::add_acl( $group , $mysql , Vhffs::Constants::ACL_VIEW , $main ) < 0 );

    return $mysql;
}


sub getall_mysql_per_group
{
        my ( $group , $main ) = @_;

        return undef if ( $group->fetch < 0 );

        my $query = "SELECT m.dbname , m.object_id , o.state FROM vhffs_mysql m, vhffs_object o WHERE m.object_id=o.object_id AND m.owner_gid='".$group->get_gid."'";

        my $request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -1;
        my @retour;

        return undef if ( $request->execute() <= 0);
        return ( $request->fetchall_hashref( 'dbname' ) );
}



sub menu
{
	my ( $class , $data ) = @_;

	my $vhffs = $data->{'vhffs'};
	my $session = $data->{'session'};
	my $user = $data->{'user'};
	my $group = $data->{'group'};
	my $cgi = $data->{'cgi'};
	my $templatesdir = $vhffs->get_config->get_templatedir;
	my $template = new HTML::Template( filename => "$templatesdir/mysql/menu.tmpl");
	$template->param( PHPMYADMIN_URL => $vhffs->get_config->get_panel_phpmyadminurl ) if( defined $vhffs->get_config->get_panel_phpmyadminurl );
	$template->param( TEXT_CREATE => gettext("Create") );
	$template->param( TEXT_MYSQL => gettext("MySQL Databases") );
	$template->param( TEXT_DBACCESS => gettext("Database Access") );

	my $output="";

	my $dbs = Vhffs::Services::Mysql::getall( $vhffs , undef, undef , $group );
	my $db;
	my $subtemplate;

	foreach $db ( @{$dbs} )
	{
		if( $db->get_status == Vhffs::Constants::ACTIVATED )
		{
			$subtemplate = new HTML::Template( filename => "$templatesdir/mysql/menu_sub.tmpl" );
			$subtemplate->param( NAME => $db->get_dbname );
			$subtemplate->param( HISTORY => gettext("History"));
            $subtemplate->param( OID => $db->get_oid );
			$output .= $subtemplate->output;
		}
		else
		{
			$subtemplate = new HTML::Template( filename => "$templatesdir/mysql/menu_sub_wait.tmpl" );
			$subtemplate->param( NAME => $db->get_dbname );
			$subtemplate->param( REASON => "( ".Vhffs::Functions::status_string_from_status_id( $db->get_status ) . " )" );
			$subtemplate->param( HISTORY => gettext("History"));
            $subtemplate->param( OID => $db->get_oid );
			$output .= $subtemplate->output;
		}
	
		
	}

	$template->param( SUB_MYSQL => $output );

	return $template->output;
}

1;
