#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.



# This file is a part of VHFFS4 Hosting Platform
# Please respect the licence of this file and the whole software

# Author: soda < dieu at gunnm dot org>

package Vhffs::Services::Cvs;

use base qw(Vhffs::Object);
use Vhffs::Group;
use strict;
use DBI;



sub new
{
    my $main;
    my $cvsroot;
    my $this;
    my $self;
    my $class;
    my $user;
    my $group;
    
    #( $class , $main , $cvsroot , $user , $group ) = @_;
    
    $class = shift;
    $main = shift;
    $cvsroot = shift;
    $user = shift;
    $group = shift;
    
    $this = {};
    
    $this = $class->SUPER::new( $main , 1 , '401' );
    
    #We return an undefined value if the user or the CVSROOT are not correct
    return undef if( ! defined ( $cvsroot ) );
    return undef if( ! ( $cvsroot =~ /[a-z0-9]+/) );
    
    $this->{'cvsroot'} = $cvsroot;
    $this->{'user'} = $user  if( defined $user );
    $this->{'group'} = $group  if( defined $group );
    
    bless( $this , $class );

    return $this;
}

sub delete
{
	my $self = shift;
	$self->fetch;

    my $query = "DELETE FROM vhffs_cvs WHERE object_id='".$self->{'object_id'}."'";
    my $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -1;

	return -1 if( $self->SUPER::delete < 0 );
	return 1;
}

sub create
{
	my $self = shift;

	return -2 if ( $self->{'user'}->fetch < 0 );
	return -3 if ( $self->{'group'}->fetch < 0 );
	
	$self->{'owner_uid'} = $self->{'user'}->get_uid;
	$self->{'owner_gid'} = $self->{'group'}->get_gid;

	my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_cvs WHERE cvsroot='" . $self->{'cvsroot'} . "'");
    my $rows = $request->execute;
    return -1 if ( $rows != 0 );

    my $oid = $self->SUPER::create();
    if ( $oid lt 0 )
	{
		return( -1 );
	}
	else
	{
		$self->{'object_id'} = $oid;
	}


	#Get the max cvs_id and compute the new cvs_id
    my $cvs_id = 1;
    my $resultuid = $self->{'db'}->{'DB_READ'}->selectall_arrayref("SELECT MAX(cvs_id) FROM vhffs_cvs");
    $cvs_id = $resultuid->[0][0] if ( defined $resultuid->[0][0] );
    $cvs_id++;


	#Finally, create the object
	my $text = "INSERT INTO vhffs_cvs VALUES( '".$cvs_id."' , '".$self->{'cvsroot'} . "','".$self->{'user'}->get_uid."','".$self->{'group'}->get_gid."' , 'TRUE' , '".$self->{'object_id'}."' )";
	$request = $self->{'db'}->{'DB_WRITE'}->prepare( $text );
	$request->execute or return -2;

	return $cvs_id;
}


sub fetch
{
    my $self = shift;
    
    my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_cvs where cvsroot='".$self->{'cvsroot'}."'") or return -1;
    
    my $rows = $request->execute() or return -3;
    
    return -1 if( $rows <= 0 );
    
    my $result = $request->fetchrow_hashref();
    
    
    foreach ( keys %{$result} )
    {
	$self->{$_} = $result->{$_}
    }


    $self->{'group'} = new Vhffs::Group( $self->{'main'} , undef ,$self->{'owner_uid'}  , $self->{'owner_gid'} );
    return -1 if( $self->{'group'}->fetch < 0 );


    $self->SUPER::fetch;
    
    return 1;
}



sub commit
{
	my $self = shift;	

	my $query = "UPDATE vhffs_cvs SET cvsroot='".$self->{'cvsroot'}."', public='".$self->{'public'}."' WHERE cvs_id='".$self->{'cvs_id'}."'";

	my $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
	$request->execute or return -1;

	return -2 if( $self->SUPER::commit < 0 );
	return 1;
}


sub set_public
{
	my $self = shift;
	$self->{'public'} = "TRUE";
}

sub set_private
{
	my $self = shift;
	$self->{'public'} = "FALSE";
}

sub is_public
{
	my $self = shift;
	
	return -1 if( ! defined $self->{'public'} );

	if( $self->{'public'} == 1 )
	{
		return 1;
	}
	else
	{
		return 0;
	}
}


sub getall
{
    my $vhffs = shift;
    my $state = shift;
    my $name = shift;
    my $group = shift;

    my $query;
    my $request;

    my $objs;
    my $result;
    my $tmp;

    $query = "SELECT c.cvsroot, c.object_id FROM  vhffs_cvs c, vhffs_object o WHERE c.object_id = o.object_id";
	$query.= " AND o.state='".$state."'" if( defined $state );
	$query.= " AND c.cvsroot LIKE '%".$name."%'" if( defined $name );
	$query.= " AND c.owner_gid='".$group->get_gid."'" if( defined $group );
    $query .= " ORDER BY c.cvsroot";
    $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );
    my $rows = $request->execute;

    return undef if( $rows == 0);

    while( $result = $request->fetchrow_hashref )
    {

        $tmp = new Vhffs::Services::Cvs( $vhffs , $result->{'cvsroot'} );
        if( ( defined ( $tmp ) ) && ( $tmp->fetch > 0 ) )
        {
            push @{$objs} , $tmp;
        }
    }
    return $objs;
}


sub set_user
{
	my ( $self , $user ) = @_;
	$self->{'user'} = $user;
}

sub set_group
{
	my ( $self , $group ) = @_;
	$self->{'group'} = $group;
}

sub get_cvsroot
{
	my $self = shift;
	return $self->{'cvsroot'};
}


sub set_cvsroot
{
	my ($self , $value) = @_;	
	$self->{'cvsroot'} = $value;
}

sub get_owneruid
{
	my( $self ) = @_;
	return $self->{'owner_uid'};
}

sub get_ownergid
{
	my $self = shift;
	return $self->{'owner_gid'};
}

sub get_title
{
	my $self;
	return $self->{'cvsroot'};
}


sub get_dir
{
    my $self = shift;
    return undef if( ! defined $self );
    
    return( $self->{'main'}->get_config->get_datadir . "/cvs/cvsroot/" . $self->get_group->get_groupname . "/" . $self->get_cvsroot );
}


sub getall_per_group
{
    my $main  = shift;
    my $group = shift;
    my @result;
    my $cvsroot;
    return undef if ( $group->fetch < 0 );
    
    my $query = "SELECT c.cvsroot , c.object_id, o.state  FROM vhffs_cvs c, vhffs_object o WHERE o.object_id=c.object_id AND c.owner_gid='".$group->get_gid."'";
    
    my $request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -1;

    
    return undef if ( $request->execute() <= 0);
    
    my $repos = $request->fetchall_hashref( 'cvsroot' );
    foreach $cvsroot ( %{$repos}  )
    {
	my $cvs = new Vhffs::Services::Cvs( $main , $cvsroot );
	push( @result , $cvs ) if( $cvs->fetch > 0 );
    }
    

    return \@result;

}




1;
