#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


# Vhffs::Services::DNS
# This file is a part of VHFFS4 program. It is used to manage domain name server (DNS)
# Please respect the licence of this program.

# Author: soda < dieu at gunnm dot org >

package Vhffs::Services::DNS;

use base qw(Vhffs::Object);
use strict;
use DBI;



sub new
{
    my $this;
    my $self;
    
    my $class = shift;
    my $main = shift;
    my $domain = shift;
    my $user = shift;
    my $group = shift;
    
    $this = {};
    
    return undef if( ! ($domain =~ /^([a-z0-9\-]+\.)+[a-z]{2,4}$/ ) );
    
    $this = $class->SUPER::new( $main , 1 , '401' );
    
    $this->{'domain'} = $domain if ( defined $domain );
    $this->{'owner_uid'} = $user->get_uid if ( defined $user );
    $this->{'owner_gid'} = $group->get_gid if ( defined $group );
    $this->{'user'} = $user;
    $this->{'group'} = $group;
    
    
    bless( $this , $class );
    
    return $this;
}



# Returns an array with ALL the DNS
# If ionly a ref of a Vhffs::Main instance if given, it returns ALL DNS objects
# If a state (of Vhffs::Constants) is given more, it returns all DNS objects which have this state
sub getall
{
    my $vhffs = shift;
    my $state = shift;
    my $name = shift;
    my $group = shift;

    my $query;
    my $request;

    my $objs;
    my $result;
    my $tmp;

	$query = "SELECT n.domain, n.object_id FROM  vhffs_dns_global n, vhffs_object o WHERE n.object_id = o.object_id";
    $query.= " AND o.state='".$state."'" if( defined $state );
    $query.= " AND n.domain LIKE '%".$name."%'" if( defined $name );
    $query.= " AND n.owner_gid='".$group->get_gid."'" if( defined $group );

	$request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );
    my $rows = $request->execute;

    return undef if( $rows <= 0);
    
    while( $result = $request->fetchrow_hashref() )
    {
		$tmp = new Vhffs::Services::DNS( $vhffs , $result->{'domain'} );
		if( ( defined ( $tmp ) ) && ( $tmp->fetch > 0 ) )
		{
	    	push @{$objs} , $tmp;
		}
    }
    return $objs;	
}




#Create the object in VHFFS database
sub create
{
    my $self = shift;
    my $conf = $self->{'main'}->get_config->get_service("dns");
    
    return -1 if ( ! defined $conf );
    

    #Check if the DNS object already exists
    my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_dns_global WHERE domain='" . $self->{'domain'} . "'");
    my $rows = $request->execute;
    return -1 if ( $rows != 0 );
    
    my $oid = $self->SUPER::create();
    return -1 if ( $oid lt 0 );
    
    
    #Exit is the no user and no group are linked to this object
    return -3 if ( ( $self->{'user'}->fetch < 0 ) || ( $self->{'group'}->fetch < 0 ) );
    

    #Get the max dns_id and compute the new dns_id
    my $dns_id = 1;
    $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_dns_global where domain='".$self->{'domain'}."'") or return -1;
    my $resultuid = $self->{'db'}->{'DB_READ'}->selectall_arrayref("SELECT MAX(dns_id) FROM vhffs_dns_global");
    $dns_id = $resultuid->[0][0] if ( defined $resultuid->[0][0] );
    $dns_id++;
    $self->{'dns_id'} = $dns_id;
    

    
    #Finally, create the object
    my $text = "INSERT INTO vhffs_dns_global VALUES( '".$dns_id."' , '".$self->{'domain'}."', '".$self->{'group'}->get_gid."' , '".$self->{'user'}->get_uid."' , '".$oid."' )";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare( $text );
    $request->execute or return -2;
    $self->{SOA}->{origin} = $self->{domain} . ".";
    $self->commit;
    
    
    # Final, create some defaults values defined in the conf file
    # Those values are defined in the config file in the <services> <dns> .... </dns> </services>
    my $ip;
    my $name;
    my $prio;
    
    if( defined $conf->{init} )
    {
	my $init = $conf->{init};
	if( defined $init->{a} )
    	{
	    foreach( keys %{$init->{a}} )
	    {
		$name = $_;
		$ip = $init->{a}{$_};	
		if( $name eq "default" )
		{
		    $self->add_a( "" , $ip );
		}
		else
		{
		    $self->add_a( $name , $ip );
		}
	    }
	}
	if( defined $init->{mx} )
	{
	    foreach( keys %{$init->{mx}} )
	    {
		$prio = $_;
		$ip = $init->{mx}{$_};
		$self->add_mx( $ip , $prio );
	    }
	}
	
	if( defined $init->{ns} )
	{
	    foreach( keys %{$init->{ns}} )
	    {
		$name = $_;
		$self->add_ns( $name );
	    }
	}   
	
    }
    
    return $dns_id;
}



# Delete this object from VHFFS database
sub delete
{
    my $self = shift;
    my $query;
    my $request;
    
    return -1 if( $self->fetch < 0);
    
    # Destroy the SOA part
    $query = "DELETE FROM vhffs_dns_soa WHERE id='".$self->{'dns_id'}."'";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -1;


    # Destroy the RR part (A, NS, PTR, ...)
    $query = "DELETE FROM vhffs_dns_rr WHERE zone='".$self->{'dns_id'}."'";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -1;
    

    # Destroy the main part of the DNS
    $query = "DELETE FROM vhffs_dns_global WHERE dns_id='".$self->{'dns_id'}."'";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -1;
    
    #Destroy the generic object
    return -2 if( $self->SUPER::delete < 0 );
    
    return 1;
}


#Get all data about this httpd object in the databse
sub fetch
{
    my $self = shift;
    my $name;
    my $key;
    
    
    #First, get informations in the dns database, in dns_global
    my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_dns_global where domain='".$self->{'domain'}."'") or return -1;
    my $rows = $request->execute() or return -3;
    return -1 if ( $rows == 0 );
    
    
    my $result = $request->fetchrow_hashref();
    
    foreach ( keys %{$result} )
    {
	$self->{$_} = $result->{$_}
    }
    
    #Second, get the SOA part
    $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_dns_soa where id='".$self->{'dns_id'}."'");
    $request->execute();
    $result = $request->fetchrow_hashref();
    
    foreach ( keys %{$result} )
    {
	$self->{SOA}->{$_} = $result->{$_}
    }
    
    
    #Get the A TYPE
    $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_dns_rr where zone='".$self->{'dns_id'}."' AND type='A'") or return -1;
    $request->execute() or return -3;
    while( $result = $request->fetchrow_hashref()) 
    {
	if( $result->{name} eq "" )
	{
	    $name = "default";
	}		
	else
	{
	    $name = $result->{name};
	}
	
	foreach( keys %{$result} )
	{
	    $self->{A}->{$name}->{$_} = $result->{$_} if ( $_ ne "name" );
	}
    }
    
    
    
    #Get the NS ZONE
    $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_dns_rr where zone='".$self->{'dns_id'}."' AND type='NS'") or return -1;
    $request->execute() or return -3;
    while( $result = $request->fetchrow_hashref()) 
    {
	$key = $result->{data};
	
	foreach( keys %{$result} )
	{
	    $self->{NS}->{$key}->{$_} = $result->{$_};
	}
    }
    
    
    
    
    #Get the CNAME TYPE
    $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_dns_rr where zone='".$self->{'dns_id'}."' AND type='CNAME'") or return -1;
    $request->execute() or return -3;
    while( $result = $request->fetchrow_hashref()) 
    {
	if( $result->{name} eq "" )
	{
	    $name = "default";
	}		
	else
	{
	    $name = $result->{name};
	}
	
	foreach( keys %{$result} )
	{
	    $self->{CNAME}->{$name}->{$_} = $result->{$_} if ( $_ ne "name" );
	}
    }
    
    
    
    
    #Get the MX TYPE
    $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_dns_rr where zone='".$self->{'dns_id'}."' AND type='MX'") or return -1;
    $self->{MX} = undef if ( $request->execute() <= 0 );
    while( $result = $request->fetchrow_hashref()) 
    {
	$key = $result->{aux};
	
	foreach( keys %{$result} )
	{
	    $self->{MX}->{$key}->{$_} = $result->{$_} if ( $_ ne "aux" );
	}
    }
    
    
    $self->SUPER::fetch;
    $self->SUPER::fetch;
}

sub get_max_rrid
{
    my ( $self ) = @_;

    my $id = 1;
    my $request = $self->{'db'}->{'DB_READ'}->selectall_arrayref("SELECT MAX(id) FROM vhffs_dns_rr");
    $id = $request->[0][0] if ( defined $request->[0][0] );
    $id++;

    return $id;	
}


# This function returns -1 if a name already exists.
# For example, if soda.gunnm.org already exists in the dns_rr table, we return -1. Otherwise, 0.
sub name_exists
{
    my ( $self , $name ) = @_;
    my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_dns_rr WHERE name='".$name."' AND zone='".$self->{'dns_id'}."' AND TYPE IN ( 'A' , 'CNAME')");
    my $rows = $request->execute;
    return 1 if ( $rows != 0 );
    
    return 0;
}


sub delete_cname
{
    my $self = shift;
    my $name = shift;

    return -1 if( ! ($name =~ /^[a-z0-9\.\-]*$/ ) );
    $name = "" if( $name eq "default" );

    my $query = "DELETE  FROM vhffs_dns_rr WHERE type='CNAME' AND zone='".$self->{'dns_id'}."' AND name='".$name."'";
    my $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
    $request->execute or return -2;

    #Update SOA
    $self->commit;
    $self->add_history("Delete the $name CNAME");
    
    return 1;
}



sub delete_ns
{
    my $self = shift;
    my $ip = shift;

    return -1 if( ! ($ip =~ /^[a-z0-9\.\-]+$/ ) );

    my $query = "DELETE  FROM vhffs_dns_rr WHERE type='NS' AND zone='".$self->{'dns_id'}."' AND data='".$ip."'";
    my $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
    $request->execute or return -2;

    $self->add_history("Delete the ns $ip");
    
    #Update SOA
    $self->commit;
    
    return 1;
}




sub delete_mx
{
    my $self = shift;
    my $aux = shift;

    return -1 if( ! ($aux =~ /^[a-z0-9\.\-]+$/ ) );

    my $query = "DELETE  FROM vhffs_dns_rr WHERE type='MX' AND zone='".$self->{'dns_id'}."' AND aux='".$aux."'";
    my $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
    $request->execute or return -2;

    $self->add_history("Delete the mx with priority $aux");
    
    #Update SOA
    $self->commit;
    return 1;
}


sub delete_a
{
    my $self = shift;
    my $name = shift;

    return -1 if( ! ($name =~ /^(?:[a-z0-9\-]*|\*)$/ ) );
    $name = "" if( $name eq "default" );

    my $query = "DELETE  FROM vhffs_dns_rr WHERE type='A' AND zone='".$self->{'dns_id'}."' AND name='".$name."'";
    my $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
    $request->execute or return -2;

    $self->add_history("Delete $name FROM domain");
    
    #Update SOA
    $self->commit;
    return 1;
}


sub update_a
{
    my ( $self , $name , $ip ) = @_;
    
    my $id = $self->get_max_rrid();
    return -1 if( ! ($ip =~ /^[a-z0-9\.\-]+$/ ) );
    return -1 if( ! ($name =~ /^(?:[a-z0-9\-]*|\*)$/ ) );
    $name = "" if( $name eq "default" );

    my $query = "UPDATE vhffs_dns_rr SET data='".$ip."' WHERE name='".$name."' AND zone='".$self->{'dns_id'}."' AND TYPE='A'";
    my $request2 = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
    $request2->execute or return -2;

    #Update SOA
    $self->commit;
    $self->add_history("Update A TYPE $name poiting now on $ip");
    return 1;
}


sub add_ns
{
    my $self = shift;
    my $ip = shift;
    my $ttl = shift;
    
    $ttl = 900 if ( ! defined $ttl );
    
    return -1 if( ! ($ip =~ /^[a-z0-9\-\.]+$/ ) );

#	return -1 if ( $self->name_exists( $name ) != 0 );

    return -1 if( ! defined $ip);
    $ip .= "." if(! ($ip =~ /.+\.$/ ) );

    my $query;
    my $request;
    my $rows;

    $query = "SELECT * FROM vhffs_dns_rr WHERE type='NS' AND data='".$ip."' AND zone='".$self->{'dns_id'}."'";
    $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
    $rows = $request->execute;

    return -1 if( $rows != 0 );
    my $id = $self->get_max_rrid();

    $query = "INSERT INTO vhffs_dns_rr VALUES( '".$id."' , '".$self->{'dns_id'}."', '' , 'NS' ,  '".$ip."' , '0' , '$ttl' )";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
    $request->execute or return -2;
    #Update SOA
    $self->commit;

    $self->add_history("Add a NS TYPE with $ip");
    return 1;
}




sub add_a
{
    my ( $self , $name , $ip , $ttl ) = @_;
    
    $ttl = 900 if ( ! defined $ttl );
    $name = "" if( $name eq "default" );
    return -1 if ( $self->name_exists( $name ) != 0 );
    return -1 if( ! ($name =~ /^(?:[a-z0-9\-]*|\*)$/ ) );

    if( ! defined $ip )
    {
	my $config = $self->{'main'}->get_config;	
	if( defined $config->get_default_a )
	{
	    $ip = $config->get_default_a;
	}
	else
	{
	    return -1;
	}
    }
    
    return -1 if( ! ($ip =~ /^[a-z0-9\.\-]+$/ ) );
    
    my $id = $self->get_max_rrid();

    my $query;
    my $request;
    my $rows;


    $query = "INSERT INTO vhffs_dns_rr VALUES( '"."$id"."' , '".$self->{'dns_id'}."', '".$name."' , 'A' ,  '".$ip."' , '0' , '$ttl' )";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
    $request->execute or return -2;
    #Update SOA
    $self->commit;

    $self->add_history("Add a A TYPE with name $name poiting on $ip");
    return 1;
}



sub update_mx
{
#	my ( $self , $name , $ip , $aux , $ttl ) = @_;
    my $self = shift;
#	my $name = shift;
    my $data = shift;
    my $aux = shift;

    my $query = "UPDATE vhffs_dns_rr SET data='".$data."' WHERE zone='".$self->{'dns_id'}."' AND aux='".$aux."' AND type='MX'";
    my $request2 = $self->{'db'}->{'DB_WRITE'}->prepare( $query );

    $self->add_history("Change the MX for priority $aux : $data");
    #Update SOA
    $self->commit;
    
    $request2->execute or return -2;
}


sub add_mx
{
    my $self = shift;
    my $ip = shift;
    my $aux = shift;
    my $ttl = shift;

    $ttl = 900 if ( ! defined $ttl );
    $aux = 10 if ( !defined $aux );

    return -1 if( ! ($ip =~ /^[a-z0-9\.\-]+$/ ) );

    my $query;
    my $request;
    my $rows;

    $ip .= ".";
    $query = "SELECT * FROM vhffs_dns_rr WHERE type='MX' AND data='".$ip."' AND zone='".$self->{'dns_id'}."'";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
    $rows = $request->execute;
    return -1 if( $rows != 0 );

    my $id = $self->get_max_rrid();


    $query = "INSERT INTO vhffs_dns_rr VALUES( '"."$id"."' , '".$self->{'dns_id'}."', '' , 'MX' ,  '".$ip."' , '$aux' , '$ttl' )";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );

    $self->add_history("Add an MX in the domain with priority $aux on $ip");
    #Update SOA
    $self->commit;
    
    $request->execute or return -2;
}



sub update_cname
{
    my $self = shift;
    my $name = shift;
    my $ip  = shift;
    
    return -1 if( ! ($name =~ /^[a-z0-9\.\-]*$/ ) );
    return -1 if( ! ($ip =~ /^[a-z0-9\.\-]+$/ ) );
    
    $ip.=".";
    my $query = "UPDATE vhffs_dns_rr SET data='".$ip."' WHERE TYPE='CNAME' AND zone='".$self->{'dns_id'}."' AND name='".$name."'";
    my $request2 = $self->{'db'}->{'DB_WRITE'}->prepare( $query );

    $self->add_history("Update CNAME $name pointing now on $ip");
    #Update SOA
    $self->commit;
    
    $request2->execute or return -2;
}

sub add_cname
{
    my $self = shift;
    my $name = shift;
    my $ip   = shift;
    my $ttl  = shift;
    
    $ttl = 900 if ( ! defined $ttl );


    $name = "" if( $name eq "default" );
    return -1  if( ! ($name =~ /^[a-z0-9\-]*$/ ) );
    return -1  if( ! ($ip =~ /[a-z0-9\.\-]+/ ) );

    return -1  if ( $self->name_exists( $name ) != 0 );


    # Add a '.' the the submitted name. Otherwise, if the user submit tata.toto.com IN CNAME foo.com
    # MyDNS will understand tata.toto.com IN CNAME foo.com.toto.com
    $ip.=".";

    my $id = $self->get_max_rrid();

    my $query = "INSERT INTO vhffs_dns_rr VALUES( '"."$id"."' , '".$self->{'dns_id'}."', '".$name."' , 'CNAME' ,  '".$ip."' , '0' , '$ttl' )";
    my $request2 = $self->{'db'}->{'DB_WRITE'}->prepare( $query );

    $self->add_history("Add a CNAME $name pointing on $ip");

    #Update SOA
    $self->commit;
    
    $request2->execute or return -2;
}

# Simply activate a domain. This is only an option for MyDNS
sub activate
{
    my $self = shift;
    $self->{SOA}->{'active'} = 1;
}




# Submit changes to the backend
sub commit
{
    my $query;
    my $self = shift;	
    

    
    my $conf = $self->{'main'}->get_config->get_service("dns");

    return -1 if ( ! defined $conf );

    return -1 if ( ! defined $self->{'dns_id'} );

    #Set some defaults values if not defined
    $self->{SOA}->{'origin'} = $self->{'domain'} if( ! defined $self->{SOA}->{'origin'} );
    $self->{SOA}->{'ttl'} = $conf->{default_ttl} if( ! defined $self->{SOA}->{'ttl'} );
    $self->{SOA}->{'ns'} = $conf->{default_ns1} if( ! defined $self->{SOA}->{'ns'} );
    $self->{SOA}->{'mbox'} = $conf->{default_mbox} if( ! defined $self->{SOA}->{'mbox'} );
    $self->{SOA}->{'serial'} = $conf->{default_serial} if( ! defined $self->{SOA}->{'serial'} );
    $self->{SOA}->{'refresh'} = $conf->{default_refresh} if( ! defined $self->{SOA}->{'refresh'} );
    $self->{SOA}->{'retry'} = $conf->{default_retry} if( ! defined $self->{SOA}->{'retry'} );
    $self->{SOA}->{'expire'} = $conf->{default_expire} if( ! defined $self->{SOA}->{'expire'} );
    $self->{SOA}->{'minimum'} = $conf->{default_minimum} if( ! defined $self->{SOA}->{'minimum'} );
    $self->{SOA}->{'active'} = 0 if( ! defined $self->{SOA}->{'active'} );


    #Convert the mail to the mailbox domain for DNS files
    $self->{SOA}->{'mbox'} =~ s/\@/\./;

	#Update the serial to refresh the domain
	my ($second,$minutes,$hours,$day,$month,$year) = localtime(time);
	my $newserial = sprintf('%.4u%.2u%.2u',$year+1900,$month+1,$day);

	if( $self->{SOA}->{serial} =~ /^$newserial/  ||  $self->{SOA}->{serial} > $newserial.'01' )
	{
		$self->{SOA}->{serial}++;
	}
	else
	{
		$self->{SOA}->{serial} = $newserial.'01';
	}
    
    #First, commit the SOA
    my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_dns_soa WHERE id='" . $self->{'dns_id'} . "'");
    my $rows = $request->execute;
    if ( $rows != 0 )
    {
	$query = "UPDATE vhffs_dns_soa SET origin='".$self->{SOA}->{'origin'}."', ns='".$self->{SOA}->{'ns'}."', mbox='".$self->{SOA}->{'mbox'}."', serial='".$self->{SOA}->{'serial'}."', refresh='".$self->{SOA}->{'refresh'}."', retry='".$self->{SOA}->{'retry'}."', expire='".$self->{SOA}->{'expire'}."', minimum='".$self->{SOA}->{'minimum'}."', ttl='".$self->{SOA}->{'ttl'}."', active='".$self->{SOA}->{'active'}."' WHERE id=$self->{'dns_id'}";
    }
    else
    {
	$query = "INSERT INTO vhffs_dns_soa VALUES ( '$self->{dns_id}' , '$self->{SOA}->{origin}' , '$self->{SOA}->{ns}' , '$self->{SOA}->{mbox}' , '$self->{SOA}->{serial}' , '$self->{SOA}->{refresh}' ,  '$self->{SOA}->{retry}' ,  '$self->{SOA}->{expire}' ,  '$self->{SOA}->{minimum}' ,  '$self->{SOA}->{ttl}' ,  '$self->{SOA}->{active}' )"; 
    }
    $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
    $request->execute or return -2;


    if( defined $self->{CNAME} )
    {
	foreach (keys %{$self->{CNAME}} )
	{
	}
    }

    if( defined $self->{A} )
    {
	foreach (keys %{$self->{A}} )
	{
	}
    }

    
    if( defined $self->{NS} )
    {
	foreach (keys %{$self->{NS}} )
	{
	}
    }


    if( defined $self->{MX} )
    {
	foreach (keys %{$self->{MX}} )
	{
	}
    }


    # Commit the object part
    $self->SUPER::commit;
}



########################################
# ACCESSORS
########################################

sub get_mx_type
{
    my $self = shift;
    return $self->{MX};
}

sub get_a_type
{
    my $self = shift;
    return $self->{A};
}

sub get_cname_type
{
    my $self = shift;
    return $self->{CNAME};
}

sub get_ns_type
{
    my $self = shift;
    return $self->{NS};
}

sub get_soa_ns
{
    my $self = shift;
    return $self->{SOA}->{'ns'};
}

sub get_soa_mbox
{
    my $self = shift;
    return $self->{SOA}->{'mbox'};
}

sub get_soa_serial
{
    my $self = shift;
    return $self->{SOA}->{'serial'};
}

sub get_soa_refresh
{
    my $self = shift;
    return $self->{SOA}->{'refresh'};
}

sub get_soa_retry
{
    my $self = shift;
    return $self->{SOA}->{'retry'};
}

sub get_soa_expire
{
    my $self = shift;
    return $self->{SOA}->{'expire'};
}

sub get_soa_minimum
{
    my $self = shift;
    return $self->{SOA}->{'minimum'};
}

sub get_soa_ttl
{
    my $self = shift;
    return $self->{SOA}->{'ttl'};
}



sub get_title
{
    my $self = shift;
    return $self->{'domain'};
}


sub set_soa_ns
{
    my $self  = shift;
    my $value = shift;

    $self->{SOA}->{'ns'} = $value;
}

sub set_soa_mbox
{
    my $self  = shift;
    my $value = shift;

    $self->{SOA}->{'mbox'} = $value;
}

sub set_soa_serial
{
    my $self  = shift;
    my $value = shift;

    $self->{SOA}->{'serial'} = $value;
}

sub set_soa_refresh
{
    my $self  = shift;
    my $value = shift;

    $self->{SOA}->{'refresh'} = $value;
}

sub set_soa_retry
{
    my $self  = shift;
    my $value = shift;

    $self->{SOA}->{'retry'} = $value;
}


sub get_ownergid
{
    my $self = shift;
    return $self->{'owner_gid'};
}



sub get_owneruid
{
    my $self = shift;
    return $self->{'owner_uid'};
}

sub set_soa_expire
{
    my $self  = shift;
    my $value = shift;
    
    $self->{SOA}->{'expire'} = $value;
}

sub set_soa_minimum
{
    my $self  = shift;
    my $value = shift;

    $self->{SOA}->{'minimum'} = $value;
}

sub set_soa_ttl
{
    my $self  = shift;
    my $value = shift;

    $self->{SOA}->{'ttl'} = $value;
}

sub set_soa_active
{
    my $self  = shift;

    $self->{SOA}->{'active'} = "Y";
}

sub set_user
{
    my $self  = shift;
    my $user = shift;

    $self->{'user'} = $user;
}

sub set_group
{
    my $self  = shift;
    my $group = shift;

    $self->{'group'} = $group;
}

sub get_domain
{
    my $self = shift;
    return $self->{domain};
}



1;
