#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::Httpd;
use Vhffs::Acl;
use Vhffs::Constants;
my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $type = $cgi->param("TYPE");
my $name = $cgi->param("NAME");
my $oid_src = $cgi->param( "OID_SRC" );
my $oid_dst = $cgi->param( "OID_DST" );
my $acl_level = $cgi->param( "ACL_TYPE" );
my $template;

my $object;
my $ok = 1;
my $title;

my $templatedir = $vhffs->get_config->get_templatedir;

$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );

my $obj_src = new Vhffs::Object( $vhffs , $oid_src , '401' );
my $obj_dst = new Vhffs::Object( $vhffs , $oid_dst , '401' );


my $message;

if( ( ! defined $oid_src ) || ( ! defined $oid_dst ) || ( ! defined $acl_level ) )
{
	$message = gettext( "CGI Error" );
}
elsif( ( ! defined $obj_src ) || ( ! defined $obj_dst ) )
{
	$message = gettext( "Object Error" );
}
elsif( ( $obj_src->fetch < 0 ) || ( $obj_dst->fetch  < 0) )
{
	$message = gettext( "Object Error" );
}
else
{
	if( (  Vhffs::Acl::what_perm_for_user( $user , $obj_dst , $vhffs ) < Vhffs::Constants::ACL_MANAGEACL ) && ( $user->is_admin != 1 ) )
	{
		$message = gettext("You're not allowed to view this object's ACL");
	}
	else
	{

		if( $acl_level == Vhffs::Constants::ACL_DENIED )
		{
			if( Vhffs::Acl::del_acl( $obj_src , $obj_dst , $vhffs ) < 0 )
			{
				$message = gettext( "Sorry, can't delete this ACL");
			 }
			else
			{
				$message = gettext( "ACL successfully deleted");
			}
		}
		else
		{
			if( Vhffs::Acl::add_acl( $obj_src , $obj_dst , $acl_level , $vhffs ) < 0 )
			{
				$message = gettext( "Sorry, can't add ACL");
			}
			else
			{
				$message = gettext( "ACL successfully modified");
			}
		}
	
	}
}
		$template->param( MESSAGE => $message );

display Vhffs::Panel::Main($panel, $template->output);
