#!/usr/bin/perl 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI qw(:standard);
use CGI::Session;
use strict;

use Vhffs::Object;
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::User;
use Vhffs::Panel::Avatar;

my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}
my $data;

			   
my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $type;

my $message;
my $cgioid;
my $filename;
my $tmpfile;
my @rstat;
my $fsize;
my $object;


$cgioid = $cgi->param( 'OID' );
$filename = $cgi->param( 'avatar' );
$object = new Vhffs::Object( $vhffs , $cgioid , '401' );

$message = "";

$|=1;

if( $filename )
{
	$tmpfile = $cgi->tmpFileName( $filename );	
}


my $templatedir = $vhffs->get_config->get_templatedir;
my $template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );

# Commit all the changes for the current user
if( $vhffs->get_config->get_panel_avatar == 0 )
{
	$message = gettext( "This platform does not provide avatar support" );
}
elsif( ! defined $cgioid )
{
	$message = gettext( "Object-ID error" );
}
elsif( ( ! defined( $object ) ) || ( $object->fetch < 0 ) )
{
	$message = gettext( "Cannot find object" );
}
elsif( ( Vhffs::Acl::what_perm_for_user( $user , $object, $vhffs ) < Vhffs::Constants::ACL_MODIFY ) && ( $cgioid != $user->get_oid ) )
{
	$message = gettext( "No enough rights" );
}
else
{
	@rstat = stat ( $tmpfile );
	$fsize = $rstat[7];

	if(  ! defined ( $filename =~ /\.png$/ ) )
	{
		$message .= gettext( "Filetype not supported" );
	}
	elsif( $fsize > 50000 )
	{
		$message .= gettext( "File to big. Max size if 5000 bytes for an avatar" );
	}
	else
	{
		my $return;
		( $type ) = ( $filename =~ ( /\.([a-zA-Z]+$)/ ) );
		if( ( $return =  Vhffs::Panel::Avatar::store_avatar( $vhffs , $object , $tmpfile , $type ) ) > 0 )
		{
			$message = gettext( "Successfull create or replace avatar" );
		}
		else
		{
			$message = gettext( "Error when upload avatar for this object" );
		}
	}
}
$template->param( MESSAGE => $message );

set_refresh_url Vhffs::Panel::Main($panel, "/panel.pl", 0);
display Vhffs::Panel::Main($panel, $template->output );
