#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Acl;
use Vhffs::Constants;
use Vhffs::Panel::Main;
use Vhffs::Functions;

my $vhffs = init Vhffs::Main;
my $cookie = Vhffs::Panel::Main::cookie_lang( $vhffs );
my $template;
my $subtemplate;
my $templatedir = $vhffs->get_config->get_templatedir;
my $cgi = new CGI;

my $name = $cgi->param("name");
$name = Vhffs::Functions::check_arg( $name );

my $user;
$user= new Vhffs::User( $vhffs , $name , '401' );




if( ! defined $name )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext( "CGI ERROR!");
	$template->param( MESSAGE => $message );
}
elsif( ( ! defined ($user= new Vhffs::User( $vhffs , $name , '401' ) ) ) || ( $user->fetch < 0 ))
{

	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext( "No such user");
	$template->param( MESSAGE => $message );

}
else
{
	$template = new HTML::Template( filename => $templatedir."/public/user.tmpl" );
	$template->param( THEME => Vhffs::Panel::Main::get_theme( $vhffs ) );
	$template->param( TEXT_USERNAME => gettext("Username") );
	$template->param( VALUE_USERNAME => $user->get_username );
	$template->param( TEXT_FIRSTNAME => gettext("Firstname") );
	$template->param( VALUE_FIRSTNAME => $user->get_firstname );
	$template->param( TEXT_LASTNAME => gettext("Lastname") );
	$template->param( VALUE_LASTNAME => $user->get_lastname );
	$template->param( TEXT_GROUPS => gettext("Groups") );
	$template->param( IMG_AVATAR => "<img src=\"/getavatar.pl?oid=".$user->get_oid."\" alt=\"".$user->get_firstname." avatar\"/>" )  if( $vhffs->get_config->get_panel_avatar() );
	$template->param( VALUE_OID => $user->get_oid );
	

	my $output = "";
	my $groups = $user->get_groups;
	my $subtemplate;
	my $group;
	if( ! defined $groups )
	{
		$template->param( VALUE_GROUPS => gettext("No group for this user") );
	}
	else
	{
		$subtemplate = new HTML::Template( filename => $templatedir."/public/group_part.tmpl" );
		
		foreach $group (@{$groups})
		{
			$subtemplate->param( VALUE => $group->get_groupname );	
			$output .= $subtemplate->output;
		}

		$template->param( VALUE_GROUPS => $output );
	}
	$subtemplate = new HTML::Template( filename => $templatedir."/public/banner.tmpl" );
	$subtemplate->param( BACK_PUBLIC => gettext( "Homepage of public area") );
	$subtemplate->param( BACK_LOGIN => gettext( "Go on login page" ) );
	$subtemplate->param( WEBSITE_LIST => gettext( "List of all websites" ) );
	$subtemplate->param( LAST_GROUPS => gettext( "Last groups" ) );
	$subtemplate->param( LAST_USERS => gettext( "Last users" ) );
	$subtemplate->param( SEARCH => gettext( "Search:" ) );

	$template->param( BANNER => $subtemplate->output );

}

print "Content-Type: text/html; charset=utf-8\n\n" . $template->output;
